@@ -1,7 +1,7 @@
 import yaoysTools.log.logutil as yaoys_log
 import yaoysTools.database.mysql as yaoys_mysql
 import yaoysTools.uniqueid.snowflake as yaoys_snowflakeid
-import yaoysTools.data.datautil as yaoys_datautil
+import yaoysTools.data.split_datautil as yaoys_datautil
 import yaoysTools.time.timeutil as yaoys_timeutil
 import yaoysTools.toolsutil.mathutil as yaoys_tools_util
 import yaoysTools.progress.progressUtil as yaoys_progress_util
