@@ -2,4 +2,4 @@ from yaoysTools.log.logutil import getLogger
 from yaoysTools.log.logutil import log_info
 from yaoysTools.log.logutil import log_error
 from yaoysTools.log.logutil import log_warn
-from yaoysTools.log.logutil import log_debug
+from yaoysTools.log.logutil import log_debug, get_log_level
